"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const data_manager_context_1 = require("next-server/dist/lib/data-manager-context");
const router_context_1 = require("next-server/dist/lib/router-context");
const unfetch_1 = __importDefault(require("unfetch"));
function createHook(fetcher, options) {
    if (!options.key) {
        throw new Error('key not provided to createHook options.');
    }
    return function useData() {
        const router = react_1.useContext(router_context_1.RouterContext);
        const dataManager = react_1.useContext(data_manager_context_1.DataManagerContext);
        const existing = dataManager.get(options.key);
        if (existing && existing.status === 'resolved') {
            return existing.result;
        }
        // @ts-ignore webpack optimization
        if (process.browser) {
            const res = unfetch_1.default(router.route === '/' ? 'index.json' : router.route + '.json').then((res) => res.json()).then((result) => {
                dataManager.overwrite(result);
            });
            throw res;
        }
        else {
            const res = fetcher().then((result) => {
                dataManager.set(options.key, {
                    status: 'resolved',
                    result,
                });
            });
            throw res;
        }
    };
}
exports.createHook = createHook;
